"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = dbHandler;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const serverless_mysql_1 = __importDefault(require("serverless-mysql"));
const grabDbSSL_1 = __importDefault(require("../../utils/backend/grabDbSSL"));
let connection = (0, serverless_mysql_1.default)({
    config: {
        host: process.env.DSQL_DB_HOST,
        user: process.env.DSQL_DB_USERNAME,
        password: process.env.DSQL_DB_PASSWORD,
        database: process.env.DSQL_DB_NAME,
        charset: "utf8mb4",
        ssl: (0, grabDbSSL_1.default)(),
    },
});
/**
 * # Main DB Handler Function
 */
function dbHandler(_a) {
    return __awaiter(this, arguments, void 0, function* ({ query, values, database, }) {
        /**
         * Switch Database
         *
         * @description If a database is provided, switch to it
         */
        let isDbCorrect = true;
        if (database) {
            connection = (0, serverless_mysql_1.default)({
                config: {
                    host: process.env.DSQL_DB_HOST,
                    user: process.env.DSQL_DB_USERNAME,
                    password: process.env.DSQL_DB_PASSWORD,
                    database: database,
                    charset: "utf8mb4",
                    ssl: (0, grabDbSSL_1.default)(),
                },
            });
        }
        if (!isDbCorrect) {
            console.log("Shell Db Handler ERROR in switching Database! Operation Failed!");
            return null;
        }
        /**
         * Declare variables
         *
         * @description Declare "results" variable
         */
        let results;
        /**
         * Fetch from db
         *
         * @description Fetch data from db if no cache
         */
        try {
            if (query && values) {
                results = yield connection.query(query, values);
            }
            else {
                results = yield connection.query(query);
            }
            /** ********************* Clean up */
            yield connection.end();
        }
        catch ( /** @type {any} */error) {
            if (process.env.FIRST_RUN) {
                return null;
            }
            console.log("ERROR in dbHandler =>", error.message);
            console.log(error);
            console.log(connection.config());
            fs_1.default.appendFileSync(path_1.default.resolve(__dirname, "../.tmp/dbErrorLogs.txt"), JSON.stringify(error, null, 4) + "\n" + Date() + "\n\n\n", "utf8");
            results = null;
        }
        /**
         * Return results
         *
         * @description Return results add to cache if "req" param is passed
         */
        if (results) {
            return JSON.parse(JSON.stringify(results));
        }
        else {
            return null;
        }
    });
}
