"use strict";
// @ts-check
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = DSQL_USER_DB_HANDLER;
const fs_1 = __importDefault(require("fs"));
const serverless_mysql_1 = __importDefault(require("serverless-mysql"));
const grabDbSSL_1 = __importDefault(require("../grabDbSSL"));
let DSQL_USER = (0, serverless_mysql_1.default)({
    config: {
        host: process.env.DSQL_DB_HOST,
        user: process.env.DSQL_DB_READ_ONLY_USERNAME,
        password: process.env.DSQL_DB_READ_ONLY_PASSWORD,
        charset: "utf8mb4",
        ssl: (0, grabDbSSL_1.default)(),
    },
});
/**
 * # DSQL user read-only DB handler
 */
function DSQL_USER_DB_HANDLER({ paradigm, database, queryString, queryValues, }) {
    try {
        return new Promise((resolve, reject) => {
            const fullAccess = (paradigm === null || paradigm === void 0 ? void 0 : paradigm.match(/full.access|^fa$/i))
                ? true
                : false;
            try {
                if (fullAccess) {
                    DSQL_USER = (0, serverless_mysql_1.default)({
                        config: {
                            host: process.env.DSQL_DB_HOST,
                            user: process.env.DSQL_DB_FULL_ACCESS_USERNAME,
                            password: process.env.DSQL_DB_FULL_ACCESS_PASSWORD,
                            database: database,
                            ssl: (0, grabDbSSL_1.default)(),
                        },
                    });
                }
                else {
                    DSQL_USER = (0, serverless_mysql_1.default)({
                        config: {
                            host: process.env.DSQL_DB_HOST,
                            user: process.env.DSQL_DB_READ_ONLY_USERNAME,
                            password: process.env.DSQL_DB_READ_ONLY_PASSWORD,
                            database: database,
                            ssl: (0, grabDbSSL_1.default)(),
                        },
                    });
                }
                /**
                 * ### Run query Function
                 * @param {any} results
                 */
                function runQuery(results) {
                    DSQL_USER.end();
                    resolve(JSON.parse(JSON.stringify(results)));
                }
                /**
                 * ### Query Error
                 * @param {any} err
                 */
                function queryError(err) {
                    DSQL_USER.end();
                    resolve({
                        error: err.message,
                        queryStringGenerated: queryString,
                        queryValuesGenerated: queryValues,
                        sql: err.sql,
                    });
                }
                if (queryValues &&
                    Array.isArray(queryValues) &&
                    queryValues[0]) {
                    DSQL_USER.query(queryString, queryValues)
                        .then(runQuery)
                        .catch(queryError);
                }
                else {
                    DSQL_USER.query(queryString)
                        .then(runQuery)
                        .catch(queryError);
                }
                ////////////////////////////////////////
            }
            catch ( /** @type {any} */error) {
                ////////////////////////////////////////
                fs_1.default.appendFileSync("./.tmp/dbErrorLogs.txt", error.message + "\n" + Date() + "\n\n\n", "utf8");
                resolve({
                    error: error.message,
                });
            }
        });
    }
    catch ( /** @type {any} */error) {
        return {
            success: false,
            error: error.message,
        };
    }
}
