"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = LOCAL_DB_HANDLER;
const serverless_mysql_1 = __importDefault(require("serverless-mysql"));
const grabDbSSL_1 = __importDefault(require("../grabDbSSL"));
/**
 * # DSQL user read-only DB handler
 */
function LOCAL_DB_HANDLER(...args) {
    return __awaiter(this, void 0, void 0, function* () {
        const MASTER = (0, serverless_mysql_1.default)({
            config: {
                host: process.env.DSQL_DB_HOST,
                user: process.env.DSQL_DB_USERNAME,
                password: process.env.DSQL_DB_PASSWORD,
                database: process.env.DSQL_DB_NAME,
                port: process.env.DSQL_DB_PORT
                    ? Number(process.env.DSQL_DB_PORT)
                    : undefined,
                charset: "utf8mb4",
                ssl: (0, grabDbSSL_1.default)(),
            },
            onConnect: () => {
                console.log("Connection Successful!");
            },
            onConnectError: (/** @type {any} */ err) => {
                console.log("Connection Error", err.message);
            },
            onError: (/** @type {any} */ err) => {
                console.log("Client Error", err.message);
            },
        });
        console.log("Querying ...");
        try {
            const results = yield MASTER.query(...args);
            yield MASTER.end();
            return JSON.parse(JSON.stringify(results));
        }
        catch ( /** @type {any} */error) {
            console.log("DB Error =>", error.message);
            return {
                success: false,
                error: error.message,
            };
        }
    });
}
