"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = NO_DB_HANDLER;
const serverless_mysql_1 = __importDefault(require("serverless-mysql"));
const grabDbSSL_1 = __importDefault(require("../grabDbSSL"));
let NO_DB = (0, serverless_mysql_1.default)({
    config: {
        host: process.env.DSQL_DB_HOST,
        user: process.env.DSQL_DB_USERNAME,
        password: process.env.DSQL_DB_PASSWORD,
        charset: "utf8mb4",
        ssl: (0, grabDbSSL_1.default)(),
    },
});
/**
 * # DSQL user read-only DB handler
 */
function NO_DB_HANDLER(...args) {
    try {
        return new Promise((resolve, reject) => {
            NO_DB.query(...args)
                .then((results) => {
                NO_DB.end();
                resolve(JSON.parse(JSON.stringify(results)));
            })
                .catch((err) => {
                NO_DB.end();
                resolve({
                    error: err.message,
                    sql: err.sql,
                });
            });
        });
    }
    catch (error) {
        return {
            success: false,
            error: error.message,
        };
    }
}
